<?xml version="1.0" encoding="UTF-8"?>
<!--
| Copyright (c) 2009-2010 Pixware SARL. All rights reserved.
|
| Author: Hussein Shafie
|
| This file is part of the XMLmind DITA Converter project.
| For conditions of distribution and use, see the accompanying LEGAL.txt file.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:ditac="http://www.xmlmind.com/ditac/schema/ditac"
                exclude-result-prefixes="xs ditac"
                version="2.0">
  
  <!-- link ============================================================== -->

  <xsl:template match="*[contains(@class,' topic/link ')]">
    <p>
      <xsl:call-template name="commonAttributes"/>
      <xsl:call-template name="linkBullet"/>
      <a>
        <xsl:copy-of select="@href"/>
        <xsl:call-template name="scopeAttribute"/>
        <xsl:call-template name="descToTitleAttribute"/>

        <xsl:call-template name="linkText">
          <xsl:with-param name="text">
            <xsl:apply-templates
                select="./*[contains(@class,' topic/linktext ')]"/>
          </xsl:with-param>
          <xsl:with-param name="autoText" select="$linkAutoText"/>
        </xsl:call-template>

        <xsl:call-template name="externalLinkIcon"/>
      </a>
    </p>
  </xsl:template>

  <xsl:template name="linkBullet">
    <xsl:text>&#x2023; </xsl:text>
  </xsl:template>

  <!-- linkText is also used to process xref. -->

  <xsl:template name="linkText">
    <xsl:param name="text" select="()"/>
    <xsl:param name="autoText" select="()"/>

    <xsl:variable name="hasText" select="string($text) != ''"/>
    <xsl:choose>
      <xsl:when test="$hasText and empty(@ditac:filled)">
        <!-- Show the text it when it has actually been specified by the
             author and that's it. -->
        <xsl:copy-of select="$text"/>
      </xsl:when>

      <xsl:otherwise>
        <!-- Auto-generated text. -->
        <xsl:variable name="showLabel"
                      select="index-of($autoText, 'number') ge 1"/>

        <xsl:variable name="showText"
                      select="index-of($autoText, 'text') ge 1"/>

        <xsl:variable name="label">
          <xsl:call-template name="linkPrefix"/>
        </xsl:variable>

        <xsl:choose>
          <xsl:when test="$label != ''">
            <xsl:choose>
              <xsl:when test="$hasText">
                <xsl:if test="$showLabel">
                  <!-- Discard the '. ' found at the end of the label. -->
                  <xsl:value-of 
                      select="substring-before($label,
                                               $title-prefix-separator1)"/>
                </xsl:if>
                <xsl:if test="$showText">
                  <xsl:if test="$showLabel">
                    <xsl:value-of select="$title-prefix-separator1"/>
                  </xsl:if>
                  <xsl:copy-of select="$text"/>
                </xsl:if>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of 
                    select="substring-before($label,
                                             $title-prefix-separator1)"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:when>
          <xsl:otherwise>
            <xsl:choose>
              <xsl:when test="$hasText">
                <xsl:copy-of select="$text"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="@href"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- linktext ========================================================== -->

  <xsl:template match="*[contains(@class,' topic/linktext ')]">
    <xsl:apply-templates/>
  </xsl:template>

  <!-- linkpool ========================================================== -->

  <xsl:template match="*[contains(@class,' topic/linkpool ')]">
    <!-- In principle, expanded by the preprocessor. -->
    <xsl:apply-templates/>
  </xsl:template>

  <!-- linklist ========================================================== -->

  <xsl:template match="*[contains(@class,' topic/linklist ')]">
    <div>
      <xsl:call-template name="commonAttributes"/>
      <xsl:apply-templates/>
    </div>
  </xsl:template>

  <!-- linkinfo ========================================================== -->

  <xsl:template match="*[contains(@class,' topic/linkinfo ')]">
    <div>
      <xsl:call-template name="commonAttributes"/>
      <xsl:apply-templates/>
    </div>
  </xsl:template>

</xsl:stylesheet>
